@@ -117,7 +117,7 @@ URL = function(_url) {
         return result
     }
     var encodeQs = function(o) {
-            output = ""
+            var output = ""
             for (key in o)
                 output += "&" + key + "=" + o[key]
             return output.slice(1)
@@ -552,7 +552,7 @@ XSubdomainRequest = function(bridgeDomain, bridgePort, bridgePath, markedHeaders
     if (!Boolean(bridgeDomain))
         throw new Error("Invalid bridge domain")
     if (!Boolean(bridgePath))
-        bridgePath = "/_/static/XSubdomainBridge.html"
+        bridgePath = "/static/XSubdomainBridge.html"
     if (!Boolean(markedHeaders))
         markedHeaders = [
             'Location',
